@@ -3,14 +3,15 @@ Main interface for pricing service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.pricing import (
+    from mypy_boto3_pricing import (
         Client,
         DescribeServicesPaginator,
         GetAttributeValuesPaginator,
         GetProductsPaginator,
         PricingClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -20,14 +21,17 @@ Usage::
     describe_services_paginator: DescribeServicesPaginator = client.get_paginator("describe_services")
     get_attribute_values_paginator: GetAttributeValuesPaginator = client.get_paginator("get_attribute_values")
     get_products_paginator: GetProductsPaginator = client.get_paginator("get_products")
+    ```
 """
-from mypy_boto3_pricing.client import PricingClient, PricingClient as Client
+from mypy_boto3_pricing.client import PricingClient
 from mypy_boto3_pricing.paginator import (
     DescribeServicesPaginator,
     GetAttributeValuesPaginator,
     GetProductsPaginator,
 )
 
+Client = PricingClient
+
 
 __all__ = (
     "Client",
