@@ -1,20 +1,22 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for pricing service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.pricing import PricingClient
-
-    session = boto3.Session()
+    from mypy_boto3_pricing import PricingClient
 
     client: PricingClient = boto3.client("pricing")
-    session_client: PricingClient = session.client("pricing")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, overload
+from typing import Any, Dict, List, Type, overload
+
 from botocore.exceptions import ClientError as Boto3ClientError
+from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_pricing.paginator import (
     DescribeServicesPaginator,
     GetAttributeValuesPaginator,
@@ -37,24 +39,24 @@ __all__ = ("PricingClient",)
 
 
 class Exceptions:
-    ClientError: Boto3ClientError
-    ExpiredNextTokenException: Boto3ClientError
-    InternalErrorException: Boto3ClientError
-    InvalidNextTokenException: Boto3ClientError
-    InvalidParameterException: Boto3ClientError
-    NotFoundException: Boto3ClientError
+    ClientError: Type[Boto3ClientError]
+    ExpiredNextTokenException: Type[Boto3ClientError]
+    InternalErrorException: Type[Boto3ClientError]
+    InvalidNextTokenException: Type[Boto3ClientError]
+    InvalidParameterException: Type[Boto3ClientError]
+    NotFoundException: Type[Boto3ClientError]
 
 
 class PricingClient:
     """
-    [Pricing.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/pricing.html#Pricing.Client)
+    [Pricing.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.44/reference/services/pricing.html#Pricing.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/pricing.html#Pricing.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.44/reference/services/pricing.html#Pricing.Client.can_paginate)
         """
 
     def describe_services(
@@ -65,7 +67,7 @@ class PricingClient:
         MaxResults: int = None,
     ) -> DescribeServicesResponseTypeDef:
         """
-        [Client.describe_services documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/pricing.html#Pricing.Client.describe_services)
+        [Client.describe_services documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.44/reference/services/pricing.html#Pricing.Client.describe_services)
         """
 
     def generate_presigned_url(
@@ -76,14 +78,14 @@ class PricingClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/pricing.html#Pricing.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.44/reference/services/pricing.html#Pricing.Client.generate_presigned_url)
         """
 
     def get_attribute_values(
         self, ServiceCode: str, AttributeName: str, NextToken: str = None, MaxResults: int = None
     ) -> GetAttributeValuesResponseTypeDef:
         """
-        [Client.get_attribute_values documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/pricing.html#Pricing.Client.get_attribute_values)
+        [Client.get_attribute_values documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.44/reference/services/pricing.html#Pricing.Client.get_attribute_values)
         """
 
     def get_products(
@@ -95,7 +97,7 @@ class PricingClient:
         MaxResults: int = None,
     ) -> GetProductsResponseTypeDef:
         """
-        [Client.get_products documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/pricing.html#Pricing.Client.get_products)
+        [Client.get_products documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.44/reference/services/pricing.html#Pricing.Client.get_products)
         """
 
     @overload
@@ -103,7 +105,7 @@ class PricingClient:
         self, operation_name: Literal["describe_services"]
     ) -> DescribeServicesPaginator:
         """
-        [Paginator.DescribeServices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/pricing.html#Pricing.Paginator.DescribeServices)
+        [Paginator.DescribeServices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.44/reference/services/pricing.html#Pricing.Paginator.DescribeServices)
         """
 
     @overload
@@ -111,11 +113,14 @@ class PricingClient:
         self, operation_name: Literal["get_attribute_values"]
     ) -> GetAttributeValuesPaginator:
         """
-        [Paginator.GetAttributeValues documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/pricing.html#Pricing.Paginator.GetAttributeValues)
+        [Paginator.GetAttributeValues documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.44/reference/services/pricing.html#Pricing.Paginator.GetAttributeValues)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_products"]) -> GetProductsPaginator:
         """
-        [Paginator.GetProducts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/pricing.html#Pricing.Paginator.GetProducts)
+        [Paginator.GetProducts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.44/reference/services/pricing.html#Pricing.Paginator.GetProducts)
         """
+
+    def get_paginator(self, operation_name: str) -> Boto3Paginator:
+        pass
