@@ -1,10 +1,14 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for pricing service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.pricing import (
+
+    from mypy_boto3_pricing import PricingClient
+    from mypy_boto3_pricing.paginator import (
         DescribeServicesPaginator,
         GetAttributeValuesPaginator,
         GetProductsPaginator,
@@ -15,10 +19,12 @@ Usage::
     describe_services_paginator: DescribeServicesPaginator = client.get_paginator("describe_services")
     get_attribute_values_paginator: GetAttributeValuesPaginator = client.get_paginator("get_attribute_values")
     get_products_paginator: GetProductsPaginator = client.get_paginator("get_products")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, List, TYPE_CHECKING
+from typing import Iterator, List
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_pricing.type_defs import (
     DescribeServicesResponseTypeDef,
     FilterTypeDef,
@@ -27,13 +33,12 @@ from mypy_boto3_pricing.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-
 __all__ = ("DescribeServicesPaginator", "GetAttributeValuesPaginator", "GetProductsPaginator")
 
 
 class DescribeServicesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeServices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/pricing.html#Pricing.Paginator.DescribeServices)
+    [Paginator.DescribeServices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.44/reference/services/pricing.html#Pricing.Paginator.DescribeServices)
     """
 
     def paginate(
@@ -43,26 +48,26 @@ class DescribeServicesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeServicesResponseTypeDef]:
         """
-        [DescribeServices.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/pricing.html#Pricing.Paginator.DescribeServices.paginate)
+        [DescribeServices.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.44/reference/services/pricing.html#Pricing.Paginator.DescribeServices.paginate)
         """
 
 
 class GetAttributeValuesPaginator(Boto3Paginator):
     """
-    [Paginator.GetAttributeValues documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/pricing.html#Pricing.Paginator.GetAttributeValues)
+    [Paginator.GetAttributeValues documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.44/reference/services/pricing.html#Pricing.Paginator.GetAttributeValues)
     """
 
     def paginate(
         self, ServiceCode: str, AttributeName: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[GetAttributeValuesResponseTypeDef]:
         """
-        [GetAttributeValues.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/pricing.html#Pricing.Paginator.GetAttributeValues.paginate)
+        [GetAttributeValues.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.44/reference/services/pricing.html#Pricing.Paginator.GetAttributeValues.paginate)
         """
 
 
 class GetProductsPaginator(Boto3Paginator):
     """
-    [Paginator.GetProducts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/pricing.html#Pricing.Paginator.GetProducts)
+    [Paginator.GetProducts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.44/reference/services/pricing.html#Pricing.Paginator.GetProducts)
     """
 
     def paginate(
@@ -73,5 +78,5 @@ class GetProductsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[GetProductsResponseTypeDef]:
         """
-        [GetProducts.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/pricing.html#Pricing.Paginator.GetProducts.paginate)
+        [GetProducts.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.44/reference/services/pricing.html#Pricing.Paginator.GetProducts.paginate)
         """
